de.baggerbagger.matomo-cljs.consent


(forget-consent-given!)

Revoke previously granted tracking consent and delete the consent cookie.

Revoke previously granted tracking consent and delete the consent cookie.
raw docstring

(forget-cookie-consent-given!)

Revoke previously granted cookie consent and delete the consent cookie.

Revoke previously granted cookie consent and delete the consent cookie.
raw docstring

give-consent!cljs

(give-consent!)

Grant tracking consent for the current page view (session only).

Grant tracking consent for the current page view (session only).
raw docstring

(give-cookie-consent!)

Grant cookie consent for the current page view (session only).

Grant cookie consent for the current page view (session only).
raw docstring

(has-cookie-consent-given? callback)

Async: check whether cookie consent has been given. Calls (callback bool).

Async: check whether cookie consent has been given. Calls (callback bool).
raw docstring

(is-consent-given? callback)

Async: check whether tracking consent has been given. Calls (callback bool).

Async: check whether tracking consent has been given. Calls (callback bool).
raw docstring

(remember-consent-given!)
(remember-consent-given! hours-to-expire)

Grant tracking consent and persist it in a cookie. hours-to-expire: omit for indefinite, or pass a number.

Grant tracking consent and persist it in a cookie.
hours-to-expire: omit for indefinite, or pass a number.
raw docstring

(remember-cookie-consent-given!)
(remember-cookie-consent-given! hours-to-expire)

Grant cookie consent and persist it. hours-to-expire: omit for indefinite, or pass a number.

Grant cookie consent and persist it.
hours-to-expire: omit for indefinite, or pass a number.
raw docstring

require-consent!cljs

(require-consent!)

Put Matomo into consent-required mode. No tracking occurs until give-consent! or remember-consent-given! is called.

Put Matomo into consent-required mode. No tracking occurs until
give-consent! or remember-consent-given! is called.
raw docstring

(require-cookie-consent!)

Put Matomo into cookie-consent-required mode. Tracking occurs but no cookies are set until give-cookie-consent! or remember-cookie-consent-given! is called.

Put Matomo into cookie-consent-required mode. Tracking occurs but no
cookies are set until give-cookie-consent! or remember-cookie-consent-given! is called.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries